@@ -92,18 +92,6 @@ fn read_all_wasm(wasm: &[u8]) -> Result<()> {
                     item?;
                 }
             }
-            AliasSection(s) => {
-                for item in s {
-                    item?;
-                }
-            }
-            InstanceSection(s) => {
-                for item in s {
-                    for arg in item?.args()? {
-                        arg?;
-                    }
-                }
-            }
             FunctionSection(s) => {
                 for item in s {
                     item?;
@@ -168,15 +156,24 @@ fn read_all_wasm(wasm: &[u8]) -> Result<()> {
                 }
             }
 
+            // Component sections
+            ComponentTypeSection(_) => todo!("component-model"),
+            ComponentImportSection(_) => todo!("component-model"),
+            ComponentFunctionSection(_) => todo!("component-model"),
+            ModuleSection { .. } => todo!("component-model"),
+            ComponentSection { .. } => todo!("component-model"),
+            InstanceSection(_) => todo!("component-model"),
+            ComponentExportSection(_) => todo!("component-model"),
+            ComponentStartSection { .. } => todo!("component-model"),
+            AliasSection(_) => todo!("component-model"),
+
             Version { .. }
             | StartSection { .. }
             | DataCountSection { .. }
             | UnknownSection { .. }
             | CustomSection { .. }
             | CodeSectionStart { .. }
-            | ModuleSectionStart { .. }
-            | ModuleSectionEntry { .. }
-            | End => {}
+            | End(_) => {}
         }
     }
     Ok(())
@@ -205,14 +202,13 @@ fn it_works_benchmark(c: &mut Criterion) {
 
 fn validate_benchmark(c: &mut Criterion) {
     fn validator() -> Validator {
-        let mut ret = Validator::new();
-        ret.wasm_features(WasmFeatures {
+        Validator::new_with_features(WasmFeatures {
             reference_types: true,
             multi_value: true,
             simd: true,
             relaxed_simd: true,
             exceptions: true,
-            module_linking: true,
+            component_model: true,
             bulk_memory: true,
             threads: true,
             tail_call: true,
@@ -223,8 +219,7 @@ fn validate_benchmark(c: &mut Criterion) {
             mutable_global: true,
             saturating_float_to_int: true,
             sign_extension: true,
-        });
-        return ret;
+        })
     }
     let mut inputs = collect_benchmark_inputs();
     // Filter out all benchmark inputs that fail to validate via `wasmparser`.
